@ECHO OFF
REM This file is a launcher program for the scenario "Crises of the New World Order"
REM It configures the events texts for each side you want to play, configures sounds
REM and will run the civ2.exe file from the scenario directory to use some files not
REM previously available to a scenario.
REM
REM Any use of this file is encouraged as long as I'm credited.
REM
REM Created by Andrew Livings, aplivings@hotmail.com
REM for the scenario "Crises of the New World Order"

:parametercheck
IF "%1"=="/?" GOTO help
IF NOT EXIST %0\..\Crises.scn GOTO error0
SET target=%0\..
if "%1"=="" goto source
set source=%1
if "%2"=="" goto target
set target=%2
goto source

:source
REM This section searches for the file "civ2.exe" in the main civ2 directory
REM This assumes you have installed the scenario under the civ2 tree, and
REM haven't renamed the .exe file.
if exist ..\civ2.exe set source=..\
if exist ..\..\civ2.exe set source=..\..\
if exist ..\..\..\civ2.exe set source=..\..\..\
if exist ..\..\..\..\civ2.exe set source=..\..\..\..\
if "%source%"=="" goto default
goto check

:menu
REM The main menu. Each choice is linked to sub-sections further on.
cls
echo.
echo Which side are you going to play as?
echo 1. I'm going to play as the Americans
echo 2. I'm going to play as the Europeans
echo 3. I'm going to play as the Russians
echo 4. I'm going to play as the Chinese
echo 5. I'm going to play as the Indians
echo 6. I'm going to play a multiplayer game
echo P. Play this scenario now
echo X. Exit this program now
choice /c:123456PX /n
if errorlevel 8 goto finished
if errorlevel 7 goto play
if errorlevel 6 goto multi
if errorlevel 5 goto indian
if errorlevel 4 goto chinese
if errorlevel 3 goto russian
if errorlevel 2 goto european
if errorlevel 1 goto american

REM These following routines are for setting the events.txt file for each side.
:multi
echo.
echo COPYING FILES
copy mpevents.txt Events.txt
pause
goto play

:indian
echo.
echo COPYING FILES
copy inevents.txt Events.txt
pause
goto play

:chinese
echo.
echo COPYING FILES
copy chevents.txt Events.txt
pause
goto play

:russian
echo.
echo COPYING FILES
copy ruevents.txt Events.txt
pause
goto play

:european
echo.
echo COPYING FILES
copy euevents.txt Events.txt
pause
goto play

:american
echo.
echo COPYING FILES
copy usevents.txt Events.txt
pause
goto play

:default
REM An error message if the civ2.exe file can't be found.
echo Your main Civ2 directory could not be located. Please use either the
echo default settings or rerun SETUP.BAT with the source path as parameter.
echo.
echo Do you want to use the default source and target paths?
echo (source:  c:\mps\civ2\)
echo.
choice /c:yn Yes or No?
if errorlevel 2 goto error1
call setup c:\mps\civ2\ %target%
goto end

:target
set target=".."

:check
REM This is a cosmetic routine. If checks that you've unzipped all the files
REM you need to play the scenario, and warns you if some files are missing. Not
REM all are needed, but it also functions as a check that there were no problems
REM with the zip files. After checking the files it creates a report file, which
REM the routine looks for each time, and if present, skips the file checks.
if exist verify.txt goto good
echo CHECKING FILE INSTALLATION
goto zip1

:zip1
if not exist 90x120.mp goto error1
if not exist 90x120.txt goto error1
if not exist Advice.txt goto error1
if not exist Chevents.txt goto error1
if not exist Cities.gif goto error1
if not exist City.gif goto error1
if not exist City.txt goto error1
if not exist Citypref.txt goto error1
if not exist Crises.scn goto error1
if not exist Crises.txt goto error1
if not exist Debug.txt goto error1
if not exist Euevents.txt goto error1
if not exist Game.txt goto error1
if not exist Icons.gif goto error1
if not exist Inevents.txt goto error1
if not exist Labels.txt goto error1
if not exist Pedia.txt goto error1
if not exist People.gif goto error1
if not exist Readme.1st goto error1
if not exist Readme.txt goto error1
if not exist Ruevents.txt goto error1
if not exist Rules.txt goto error1
if not exist Terrain1.gif goto error1
if not exist Terrain2.gif goto error1
if not exist Title.gif goto error1
if not exist Tutorial.txt goto error1
if not exist Units.gif goto error1
if not exist Usevents.txt goto error1
goto zip2

:zip2
echo. Did you download Crises2.zip? (City sounds)
choice /c:yn Yes or No?
if errorlevel 2 goto zip3
if not exist sound\Aqueduct.wav goto error2
if not exist sound\Civdisor.wav goto error2
if not exist sound\Menuend.wav goto error2
if not exist sound\Menuok.wav goto error2
if not exist sound\Newbank.wav goto error2
if not exist sound\Newgovt.wav goto error2
goto zip3

:zip3
echo. Did you download Crises3.zip? (Unit sounds)
choice /c:yn Yes or No?
if errorlevel 2 goto zip4
if not exist sound\Biggun.wav goto error3
if not exist sound\Cavalry.wav goto error3
if not exist sound\Custom1.wav goto error3
if not exist sound\Custom2.wav goto error3
if not exist sound\Custom3.wav goto error3
if not exist sound\Elephant.wav goto error3
if not exist sound\Infantry.wav goto error3
if not exist sound\Jetbomb.wav goto error3
if not exist sound\Jetcrash.wav goto error3
if not exist sound\Largexpl.wav goto error3
if not exist sound\Mchnguns.wav goto error3
if not exist sound\Medgun.wav goto error3
if not exist sound\Missile.wav goto error3
if not exist sound\Nukexplo.wav goto error3
if not exist sound\Swordfgt.wav goto error3
if not exist sound\Swrdhors.wav goto error3
goto zip4

:zip4
echo. Did you download Crises4.zip? (Diplomatic sounds)
choice /c:yn Yes or No?
if errorlevel 2 goto verify
if not exist sound\drumal.wav goto error4
if not exist sound\drumbl.wav goto error4
if not exist sound\drumcl.wav goto error4
if not exist sound\fanfare1.wav goto error4
if not exist sound\fanfare2.wav goto error4
if not exist sound\fanfare3.wav goto error4
if not exist sound\fanfare4.wav goto error4
if not exist sound\fanfare5.wav goto error4
if not exist sound\fanfare6.wav goto error4
if not exist sound\fanfare7.wav goto error4
goto verify

:verify
dir  >> verify.txt
dir sound >> verify.txt
goto good

:good
REM By this stage, the program has located the main civ2 directory (and by
REM implication, the civ2 sound subdirectory), has established the program
REM has not been run before, and will now copy the sounds it needs, some of
REM which are from the civ2 sound directory.
if exist sound\extra8.wav goto step2
echo PREPARING TO COPY SOUNDS
goto step1

:step1
if not exist sound\swordfgt.wav goto error6
echo Commence copying ...
copy sound\swordfgt.wav sound\Extra1.wav
copy sound\swordfgt.wav sound\Extra2.wav
copy sound\swordfgt.wav sound\Extra3.wav
copy sound\swordfgt.wav sound\Extra4.wav
copy sound\swordfgt.wav sound\Extra5.wav
copy sound\swordfgt.wav sound\Extra6.wav
copy sound\swordfgt.wav sound\Extra7.wav
copy sound\swordfgt.wav sound\Extra8.wav
goto step2

:step2
if exist sound\crwdbugl.wav goto menu
if not exist %source%\sound\crwdbugl.wav goto error7
if not exist %source%\sound\bldspcsh.wav goto error7
if not exist %source%\sound\newbank.wav goto error7
copy %source%\sound\crwdbugl.wav sound\Crwdbugl.wav
copy %source%\sound\bldspcsh.wav sound\Bldcity.wav
copy %source%\sound\newbank.wav sound\Mrktplce.wav
echo.
echo Sound effects successfully installed!
Pause
goto menu

:error0
ECHO The scenario file could not be found. Please make sure this batch
ECHO file is located in the same directory as the scenario.
ECHO.
goto finished

:error1
echo There was a file missing from the archive crises1.zip
echo They may have been a transmission error so please download
echo this file again. The scenario may not function correctly
echo without it
echo Do you wish to continue
choice /c:yn Yes or No?
if errorlevel 2 goto finished
goto zip2

:error2
echo There was a file missing from the archive crises2.zip
echo They may have been a transmission error so please download
echo this file again. The scenario may not function correctly
echo without it
echo Do you wish to continue
choice /c:yn Yes or No?
if errorlevel 2 goto finished
goto zip3

:error3
echo There was a file missing from the archive crises3.zip
echo They may have been a transmission error so please download
echo this file again. The scenario may not function correctly
echo without it
echo Do you wish to continue
choice /c:yn Yes or No?
if errorlevel 2 goto finished
goto zip4

:error4
echo There was a file missing from the archive crises4.zip
echo They may have been a transmission error so please download
echo this file again. The scenario may not function correctly
echo without it
echo Do you wish to continue
choice /c:yn Yes or No?
if errorlevel 2 goto finished
goto good

:error5
echo.
echo Please rerun SETUP.BAT and specify the source and (if necessary) the
echo target directory.
echo.
goto syntax

:error6
echo The sound file Swordfgt.wav was not found. Possible reasons for this are:
echo a) You have not extracted it from crises3.zip to the scenario sound directory.
echo b) You have specified the wrong target directory.
echo c) The default target directory doesn't correspond to the actual target
echo    directory (*\sound).
echo.
echo Please identify the problem, solve it and rerun SETUP.BAT!
pause
goto syntax

:error7
echo At least one of the sound files from the Civ2 sound directory was not found.
echo Possible reasons for this are:
echo a) You have specified the wrong source directory.
echo b) The default source directory doesn't correspond to the actual source
echo    directory. 
echo    In case of a) or b) specify the correct directory when running setup.bat.
echo c) There are sound files missing in the specified directory.
echo    The required sound files are: crdbugl.wav
echo                                  bldspcsh.wav
echo                                  newbank.wav
echo.
echo Please identify the problem, solve it and rerun SETUP.BAT!
pause
goto syntax

:syntax
echo Please use the following syntax:
echo.
echo [path]sndsetup [source dir] [target dir]
echo.
echo [path]              If necessary specify the path for SETUP.BAT.
echo [source dir]        The path of the main Civ2 directory.
echo [target dir]        The path of the directory for this scenario.
echo.
echo Don't forget the backslash at the end of the source and target path.
echo.
echo If running SETUP.BAT without any parameters doesn't work try running 
echo SETUP.BAT with the above mentioned parameters.
echo.
echo Example:
echo c:\civ2\scenario\crises~1\setup c:\civ2\ c:\civ2\scenario\crises~1\
echo.
echo SETUP.BAT was terminated. Please rerun.
pause
goto menu

:help
REM This is just another cosmetic addition - describing what the batch file is
REM used for.
ECHO This file is a launcher program for the scenario "Crises of 
ECHO the New World Order" It configures the events texts for each side
ECHO you want to play, and configures the sound files, some of which are
ECHO taken from the main civ2 sound directory. It locates the "Civ2.exe"
ECHO file and will launch this if you select the option to "Play this
ECHO scenario now". This starts the game from the scenario directory,
ECHO so it uses some extra files not usually needed because they are in
ECHO the main civ2 directory, and so allows the scenario to use these
ECHO amended files, notably: Icons.gif, city.gif, civ2.dat, and
ECHO menuloop.wav. This has no effect on your main civ2 directory.
pause
GOTO menu

:play
REM I REMMED out some lines I found I didn't need - but that's how
REM I thought it would be before. The first three lines check for
REM essential game files, without which the game won't run. I included
REM my own debug.txt and city.gif, so this is just a safeguard.
if not exist debug.txt copy %source%debug.txt Debug.txt
if not exist menu.txt copy %source%menu.txt Menu.txt
if not exist city.gif copy %source%city.gif City.gif
REM md %target%\backup
REM copy %source%\sound\menuloop.wav %target%\backup\menuloop.wav
REM copy %source%city.gif %target%\backup\city.gif
REM copy %source%icons.gif %target%\backup\icons.gif
REM copy %target%\sound\drumal.wav %source%\sound\menuloop.wav
REM copy %target%\city.gif %source%city.gif
REM copy %target%\icons.gif %source%icons.gif
echo NOW RUNNING CIV2.EXE (KEEP THIS BATCH FILE OPEN FOR NOW)
REM The next command line starts the civ2.exe file, and by using the /w (wait)
REM flag, we can use further line commands after civ2 has closed down again.
REM If we wanted to run civ2 normally, we could use the command lines:
REM cd\%source%
REM start/w civ2.exe
REM But that would be rather retro.
start /w %source%\civ2.exe
REM move %target%\backup\menuloop.wav %source%\sound\Menuloop.wav
REM move %target%\backup\city.gif %source%City.gif
REM move %target%\backup\icons.gif %source%Icons.gif

:finished
echo.
echo ************************************
echo *   This batch file is finished    *
echo *                                  *
echo *  Please close this MS-DOS Window *
echo ************************************

:end
set source=
set target=